.. _tutorials:



Distributed machine learning training
======================================

Here you can find a collection of tutorials for distributing PyTorch and Tensorflow based workflows.


Distributed ML with PyTorch
---------------------------

.. toctree::
   :maxdepth: 1
   :numbered:

   distrib-ml/torch_tutorial_0_basics
   distrib-ml/torch_tutorial_1_mnist
   distrib-ml/torch_tutorial_2_trainer_class
   distrib-ml/torch-tutorial-GAN
   distrib-ml/torch_scaling_test
   distrib-ml/torch-tutorial-containers
   distrib-ml/torch_tutorial_kubeflow_1.rst


Distributed ML with TensorFlow
------------------------------

.. toctree::
   :maxdepth: 1
   :numbered:

   distrib-ml/tf_tutorial_0_basics
   distrib-ml/tf_tutorial_1_imagenet
   distrib-ml/tf_scaling_test


Machine learning workflows
===========================

Here you can find a collection of tutorials for various complexity ML workflows.

.. toctree::
   :maxdepth: 1
   
   workflows/01-pipeline-introduction/tutorial_0_basic_workflow
   workflows/02-pipeline-configuration/tutorial_1_intermediate_workflow
   workflows/03-dag-workflows/tutorial_2_advanced_workflow
   workflows/04_itwinai_argparser
 

Hyperparameter Optimization Workflows
======================================

This tutorial provides an overview of Hyperparameter Optimization (HPO) workflows.

.. toctree::
   :maxdepth: 1

   hpo-workflows/hpo-basic-integration
   hpo-workflows/hpo-torchtrainer-integration